@@ -76,8 +76,8 @@ rococo.test.numeric <- function(x, y, similarity=c("linear", "exp", "gauss",
           else
               tnlist <- list(name="user-defined t-norm", def=tnorm)
 
-          if (require("compiler"))
-               tnorm <- cmpfun(tnorm)
+          if (requireNamespace("compiler", quietly=TRUE))
+               tnorm <- compiler::cmpfun(tnorm)
      }
      else
          stop("'tnorm' should be valid string or a function of two arguments, ",
